@@ -2,6 +2,7 @@ use strict;
 use warnings FATAL => 'all';
 
 package HTML::Tested::List::Pager;
+use HTML::Tested::Value;
 
 sub new {
 	my ($class, $entries_per_page) = @_;
@@ -13,7 +14,7 @@ sub entries_per_page { return shift()->{entries_per_page}; }
 sub init {
 	my ($self, $the_list, $parent) = @_;
 	my $ln = $the_list->name;
-	$parent->make_tested_value("$ln\_current_page");
+	$parent->ht_add_widget("HTML::Tested::Value", "$ln\_current_page");
 }
 
 sub render {
